@@ -1,9 +1,10 @@
 # -*- perl -*-
 
 #
+# $Id: Util.pm,v 1.3 2003/02/05 16:12:30 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 2003,2004,2012 Slaven Rezic. All rights reserved.
+# Copyright (C) 2003 Slaven Rezic. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -14,10 +15,10 @@
 package Tk::Pod::Util;
 use strict;
 use vars qw($VERSION @EXPORT_OK);
-$VERSION = '5.05';
+$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 use base qw(Exporter);
-@EXPORT_OK = qw(is_in_path is_interactive detect_window_manager start_browser);
+@EXPORT_OK = qw(is_in_path is_interactive detect_window_manager);
 
 # REPO BEGIN
 # REPO NAME is_in_path /home/e/eserte/src/repository
@@ -49,8 +50,8 @@ sub is_interactive {
 	return -t STDIN && -t STDOUT;
     }
 
-    # from perlfaq8 (with glitches)
-    open(TTY, "/dev/tty") or return 0;
+    # from perlfaq8
+    open(TTY, "/dev/tty") or die $!;
     my $tpgrp = POSIX::tcgetpgrp(fileno(*TTY));
     my $pgrp = getpgrp();
     if ($tpgrp == $pgrp) {
@@ -73,7 +74,7 @@ sub detect_window_manager {
        ) {
 	return "kde";
     }
-    "x11"; # generic X11 window manager
+    "x11";
 }
 
 sub get_property {
@@ -86,38 +87,16 @@ sub get_property {
     @ret;
 }
 
-sub start_browser {
-    my($url) = @_;
-
-    if (!defined &Tk::Pod::WWWBrowser::start_browser && !eval { require Tk::Pod::WWWBrowser }) {
-	*Tk::Pod::WWWBrowser::start_browser = sub {
-	    my $url = shift;
-	    if ($^O eq 'MSWin32') {
-		system(qq{start explorer "$url"});
-	    } elsif ($^O eq 'cygwin') {
-		system(qq{explorer "$url" &});
-	    } elsif (is_in_path("firefox")) {
-		system(qq{firefox "$url" &});
-	    } else { # last fallback
-		system(qq{mozilla "$url" &});
-	    }
-	};
-    }
-
-    Tk::Pod::WWWBrowser::start_browser($url);
-}
-
 1;
 
 __END__
 
 =head1 NAME
 
-Tk::Pod::Util - Tk::Pod specific utility functions
+Tk::Pod::Util - utility functions
 
 =head1 DESCRIPTION
 
-This module contains a collection of utility functions for Tk::Pod and
-is not meant for public use.
+This module contains a collection of utility functions for Tk::Pod.
 
 =cut
